@@ -14,7 +14,7 @@ class ClientConnectTestCase(unittest.TestCase):
         with self.assertRaises(ImproperlyConfigured):
             client_connect()
 
-    @override_settings(ASANA_ACCESS_TOKEN='foo')
+    @override_settings(ASANA_ACCESS_TOKEN='foo', ASANA_WORKSPACE='foo')
     def test_connect_access_token(self):
         with self.assertRaises(NoAuthorizationError):
             try:
